Tests only be run from the in the main studio directory
use "python -m pytest tests/{testname}" to run individual tests
use "python -m pytest tests" to run all tests

Set cloud enviornment in test_config.yaml prior to running tests
